@@ -9,7 +9,7 @@
 # housekeeping
 ########################################################################
 
-package Object::Trampoline;
+package Object::Trampoline  1.42;
 use v5.12;
 
 use Carp;
@@ -18,14 +18,13 @@ use Carp;
 # package variables
 ########################################################################
 
-our $VERSION    = '1.41';
-$VERSION        = eval $VERSION;
-
 # minimal sanity check for valid class name, used in both
 # O::T and O::T::U.
 
 my $pkg_rx      = qr{^ [_A-Za-z](?:\w*) (?:::\w+)* $}x;
 
+my $bounce_pkg  = 'Object::Trampoline::Bounce';
+
 ########################################################################
 # AUTOLOAD is the only public interface
 ########################################################################
@@ -51,6 +50,13 @@ my $pkg_rx      = qr{^ [_A-Za-z](?:\w*) (?:::\w+)* $}x;
 
 our $AUTOLOAD = '';
 
+sub delayed
+{
+    my ( $undef, $handler, @argz ) = @_;
+
+    bless sub { $handler->( @argz ) }, $bounce_pkg
+}
+
 AUTOLOAD
 {
     # discard this class: once here it is used up.
@@ -66,7 +72,7 @@ AUTOLOAD
 
     my $sub     = sub { $proto->$method( @argz ) };
 
-    bless $sub, 'Object::Trampoline::Bounce'
+    bless $sub, $bounce_pkg
 }
 
 ########################################################################
@@ -319,6 +325,49 @@ simplifies runtime definition of handler classes.
     my $post_fork_object
     = bless sub { WhatEver->new( ... ) }, 'Object::Trampoline::Bounce';
 
+    # there are times it is convienent to delay calling 
+    # a lexical sub, say a factory object or lexically-
+    # scoped utility sub.
+    # 
+    # lacking the name of a method and a class, this has to use
+    # different mechanism. calling O::T::delayed with a subref
+    # and arguments will delay calling the subref until the object
+    # is accessed.
+    #
+    # note that this will fail if $handler is not a subref; for 
+    # calling methods by name use the syntax described above.
+
+    my $handler
+    = sub
+    {
+        # extract connect values at runtime.
+
+        DBI->connect( @Database{ qw( dsn usr pwd attr ) } );
+    };
+
+    my $dbh = Object::Trampoline->delayed( $handler, @argz );
+
+    # or 
+
+    my $gen_dbh
+    = do
+    {
+        # extract DBConfig at compile time, delay 
+        # constructing the object. this gives the 
+        # advantage of validating the arguments at
+        # compile time, delaying the actual construction.
+
+        my $dsn     = $Database{ dsn } or die "...";
+        my $user    = ... ;
+        my $pass    = ... ;
+        my $attr    = ... ;
+
+        sub { DBI->connect( $dsn, $user, $pass, $attr ) }
+    };
+
+    my $dbh = Object::Trampoline->delayed( $gen_dbh );
+
+
 =head1 DESCRIPTION
 
 There are times when constructing an object is expensive
